Execution functions
Functions
- exec_
from_ files - exec_
from_ lines - run and execute SQL statements and commands from a file, against a context with the given print options
- execute_
from_ repl - run and execute SQL statements and commands against a context with the given print options