pub async fn execute_from_repl(
ctx: &KapotContext,
print_options: &mut PrintOptions,
)Expand description
run and execute SQL statements and commands against a context with the given print options
pub async fn execute_from_repl(
ctx: &KapotContext,
print_options: &mut PrintOptions,
)run and execute SQL statements and commands against a context with the given print options