Module exec

Execution functions

Functions

exec_from_files
exec_from_lines
run and execute SQL statements and commands from a file, against a context with the given print options
execute_from_repl
run and execute SQL statements and commands against a context with the given print options